@@ -12,10 +12,10 @@ pub mod ansible_facts_request;
 pub use self::ansible_facts_request::AnsibleFactsRequest;
 pub mod appliance;
 pub use self::appliance::Appliance;
+pub mod appliance_key_pair;
+pub use self::appliance_key_pair::ApplianceKeyPair;
 pub mod appliance_public_key;
 pub use self::appliance_public_key::AppliancePublicKey;
-pub mod appliance_public_key_request;
-pub use self::appliance_public_key_request::AppliancePublicKeyRequest;
 pub mod appliance_request;
 pub use self::appliance_request::ApplianceRequest;
 pub mod artifact_types_enum;
@@ -172,8 +172,6 @@ pub mod patched_alert_request;
 pub use self::patched_alert_request::PatchedAlertRequest;
 pub mod patched_ansible_facts_request;
 pub use self::patched_ansible_facts_request::PatchedAnsibleFactsRequest;
-pub mod patched_appliance_public_key_request;
-pub use self::patched_appliance_public_key_request::PatchedAppliancePublicKeyRequest;
 pub mod patched_appliance_request;
 pub use self::patched_appliance_request::PatchedApplianceRequest;
 pub mod patched_camera_request;
